@@ -61,7 +61,6 @@ class ImagesClient(base_compute_client.BaseComputeClient):
     def show_image(self, image_id):
         """Return the details of a single image."""
         resp, body = self.get("images/%s" % image_id)
-        self.expected_success(200, resp.status)
         body = json.loads(body)
         self.validate_response(schema.get_image, resp, body)
         return rest_client.ResponseBody(resp, body)
@@ -131,8 +130,10 @@ class ImagesClient(base_compute_client.BaseComputeClient):
         return rest_client.ResponseBody(resp, body)
 
     def is_resource_deleted(self, id):
+        # Added status check for user with admin role
         try:
-            self.show_image(id)
+            if self.show_image(id)['image']['status'] == 'DELETED':
+                return True
         except lib_exc.NotFound:
             return True
         return False
